==> cyphermed-2.1.21-py3-none-any.whl: cyphermed/models/create_group_access_body_data_paths.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field


if TYPE_CHECKING:
    from ..models.wrd_permissions import WRDPermissions


T = TypeVar("T", bound="CreateGroupAccessBodyDataPaths")


@_attrs_define
class CreateGroupAccessBodyDataPaths:
    """Dictionary of accessible data paths and their CRUD permissions"""

    additional_properties: Dict[str, "WRDPermissions"] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.wrd_permissions import WRDPermissions

        d = src_dict.copy()
        create_group_access_body_data_paths = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = WRDPermissions.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        create_group_access_body_data_paths.additional_properties = additional_properties
        return create_group_access_body_data_paths

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "WRDPermissions":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "WRDPermissions") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> cyphermed-2.2.3-py3-none-any.whl: cyphermed/models/create_group_access_body_data_paths.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field


if TYPE_CHECKING:
    from ..models.wrud_permissions import WRUDPermissions


T = TypeVar("T", bound="CreateGroupAccessBodyDataPaths")


@_attrs_define
class CreateGroupAccessBodyDataPaths:
    """Dictionary of accessible data paths and their CRUD permissions"""

    additional_properties: Dict[str, "WRUDPermissions"] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.wrud_permissions import WRUDPermissions

        d = src_dict.copy()
        create_group_access_body_data_paths = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = WRUDPermissions.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        create_group_access_body_data_paths.additional_properties = additional_properties
        return create_group_access_body_data_paths

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "WRUDPermissions":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "WRUDPermissions") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
